<?php
 /*
	Author: Zourbuth
	Author URI: http://zourbuth.com
	@since 1.2.1

    Copyright 2013 zourbuth (email : zourbuth@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class Extended_Tags_Utils {
	function __construct() {
		add_filter( 'the_content', array( &$this, 'the_content' ) );
		add_shortcode( 'extended-tags', array( &$this, 'add_shortcode' ) );
		add_filter( 'wp_generate_tag_cloud', array( &$this, 'generate_tag_cloud' ), 1, 3 );
		add_filter( 'get_terms_args', array( &$this, 'get_terms_args' ), 1, 2 );
	}
		
	
	function get_terms_args( $args, $taxonomies ) {
		if( ! isset( $args['extended'] ) ) // check if this from plugin
			return $args;
				
		$args['order'] = $args['order_'];
		$args['orderby'] = $args['order_by'];

		return $args;
	}
	
	
	function the_content( $content ) {
		$option = get_option( EXTENDED_TAGS_WIDGET_SLUG );
		
		if( is_single() && 'post' == get_post_type() && $option['display_post_tags'] ) {
			$args = array(
				'order' 			=> 'ASC',
				'orderby' 			=> 'name',
				'format' 			=> 'flat',
				'style' 			=> $option['post_tag_style'],
				'include' 			=> array(),
				'exclude' 			=> array(),
				'unit' 				=> 'pt',
				'smallest' 			=> 8,
				'largest' 			=> 22,
				'link' 				=> 'view',
				'number' 			=> 45,
				'separator' 		=> '',
				'child_of' 			=> '',
				'parent' 			=> '',
				'taxonomy' 			=> 'post_tag',
				'hide_empty' 		=> 1,
				'pad_counts' 		=> false,
				'search' 			=> '',
				'name__like' 		=> '',
				'echo'				=> false,
			);
		
			$html = '';
			$tags = wp_get_post_tags( get_the_ID() );
			
			if( $tags ) {
				foreach( $tags as $tag ) {
					$html .= "<a class='tag-link-{$tag->term_id}' href='". get_term_link( $tag, 'post_tag' ) ."'><span>{$tag->name}</span></a> ";
				}
			}

			$tags = "<p class='{$args['taxonomy']}-cloud term-cloud extended-tags extended-tags-{$args['style']}'>$html<br class='clear' /></p>";
		
			$content = $content . $tags;
		}

		return $content;
	}
	
	
	/**
	 * Filter for 'wp_generate_tag_cloud'
	 * @file \wp-includes\category-template.php
	 * @return HTML.
	 * @since 1.2.1
	**/
	function generate_tag_cloud( $return, $tags, $args ) {
		if( ! isset( $args['extended'] ) || ! $args['pad_counts'] ) // check if this from plugin
			return $return;

		$a = array();
		
		foreach ( $tags as $key => $tag ) {
			$count = " ({$tag->count})";
			$repl = str_replace( '</a>', $count . '</span></a>', $return[$key] );
			$a[] = $repl;
		}
		
		switch ( $args['display'] ) {
			case 'list' :
				$return = "<ul class='wp-tag-cloud'>\n\t<li>";
				$return .= join( "</li>\n\t<li>", $a );
				$return .= "</li>\n</ul>\n";
				break;
			default :
				$return = join( $args['separator'], $a );
				break;
		}		
		
		return $return;
	}
	
	
	/**
	 * Shortcode function
	 * Uses add_shortcode
	 * @return HTML.
	 * @since 1.5
	**/
	function add_shortcode( $atts, $content ) {
		$args = shortcode_atts( extended_tags_defaults_args(), $atts );
  
		$options = get_option( 'widget_extended-tags' );
		$widget_id = $args['id'];
		$args = $options[$widget_id]; 	// overwrite
		$args['id'] = $widget_id;		// add the id for load more post link
		
		return extended_tags( $args );
	}

} new Extended_Tags_Utils();


/**
 * Setup widget default arguments
 * @since 1.2.1
 */
function extended_tags_defaults_args() {
	$defaults = array(
		'id' 				=> '',
		'widget_id'			=> '',
		'title' 			=> '',
		'title_icon'		=> '',
		'order' 			=> 'ASC',
		'orderby' 			=> 'name',		
		'display' 			=> 'flat',
		'format' 			=> 'array',
		'style' 			=> 'bluerr',
		'include' 			=> array(),
		'exclude' 			=> array(),
		'unit' 				=> 'pt',
		'smallest' 			=> 8,
		'largest' 			=> 22,
		'link' 				=> 'view',
		'number' 			=> 45,
		'separator' 		=> '',
		'child_of' 			=> '',
		'parent' 			=> '',
		'taxonomy' 			=> 'post_tag',
		'hide_empty' 		=> 1,
		'pad_counts' 		=> false,
		'current_tags' 		=> false,
		'search' 			=> '',
		'name__like' 		=> '',
		'bgImage' 			=> '',
		'echo'				=>	false,
		'toggle_active'		=> array( 0 => true, 1 => false, 2 => false, 3 => false, 4 => false, 5 => false ),			
		'intro_text' 		=> '',
		'outro_text' 		=> '',
		'customstylescript'	=> '',
		'extended'			=> true
	);
	
	return $defaults;
}


/**
 * Outputs the widget based on the arguments input through the widget controls.
 * @since 1.2.1
 */
function extended_tags( $args ) {
	
	$html = $tags = '';
	$args = wp_parse_args( (array) $args, extended_tags_defaults_args() );	
	$args['order_by'] = $args['orderby']; // hold user data while wp_tag_cloud() is always set to 'count'
	$args['order_']   = $args['order']; // hold user data while wp_tag_cloud() is always set to 'count'
	
	// Print intro text if exist
	if ( ! empty( $args['intro_text'] ) )
		$html .= '<p class="'. $args['id'] . '-intro-text intro-text">' . $args['intro_text'] . '</p>';

	// Get the current post tags if checked
	// Make sure current page is a single post
	if( $args['current_tags'] && get_the_ID() && is_single() ) {
		$terms = wp_get_post_terms( get_the_ID(), $args['taxonomy'] );
		if ( ! is_wp_error( $terms ) ) {
			if ( ! empty( $terms ) || ! is_wp_error( $terms ) ) {
				$inc_tags = array();
				foreach ( $terms as $k => $t ) {
					$inc_tags[] = $t->term_id;					
				}
				$args['include'] = join( ', ', $inc_tags );
			}
		}
	}	

	// Pad counts
	if( $args['pad_counts'] )
		$args['format'] = 'array';
	else
		$args['format'] = $args['display'];

	// Get the tag cloud
	$tags = str_replace( array( "\r", "\n", "\t" ), ' ', wp_tag_cloud( $args ) );
	$tags = str_replace( "'>", "'><span>", $tags );
	$tags = str_replace( '</a>', '</span></a>', $tags );

	// If $format should be flat, wrap it in the <p> element.
	if ( 'flat' == $args['display'] )
		$tags = '<p class="' . $args['taxonomy'] . '-cloud term-cloud extended-tags extended-tags-' . $args['style'] . '">' . $tags . '<br class="clear" /></p>';

	// Output the tag cloud
	$html .= $tags;

	// Print outro text if exist
	if ( ! empty( $args['outro_text'] ) )
		$html .= '<p class="'. $args['id'] . '-outro-text outro-text">' . $args['outro_text'] . '</p>';

	return $html;
}
?>