<?php
/*
    The Countdown Pro Settings
	
	Copyright 2012  zourbuth.com  (email : zourbuth@gmail.com)

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License, version 2, as 
    published by the Free Software Foundation.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
*/

class Extended_Tags_Settings extends Total_Options {
	
	var $textdomain;
	/**
	 * Construct	 
	 * @since 1.0
	 */
	function __construct() {
		$this->textdomain = 'flatsheet';
		
        parent::__construct( array(
			'sections'	=> array (
							'general'		=> __( 'General', $this->textdomain ),
							'advanced'		=> __( 'Advanced', $this->textdomain )		
						),
			'lang'		=> EXTENDED_TAGS_WIDGET_TEXTDOMAIN,
			'title'		=> 'Exteded Tags Settings',
			'slug'		=> EXTENDED_TAGS_WIDGET_SLUG,
		));
	}
	
	
	/**
	 * http://codex.wordpress.org/Function_Reference/add_theme_page
	 * add_theme_page( $page_title, $menu_title, $capability, $menu_slug, $function );
	 * @since 1.0
	 */	
	function add_pages() {	
		$menu = add_options_page( $this->title, 'Exteded Tags', 'manage_options', $this->slug, array( &$this, 'display_page' ) );
		add_action( "admin_print_styles-$menu", array( &$this, 'styles' ) );
		add_action( "admin_print_scripts-$menu", array( &$this, 'scripts' ) );	
	}	

	
	/**
	 * Settings and defaults
	 * @since 1.0
	 */
	function create_options() {
		
		/* General Settings
		===========================================*/
		$this->options['display_post_tags'] = array(
			'section' => 'general',
			'title'   => __( 'Display Post Tags', $this->textdomain ),
			'desc'    => __( 'Check to display post tags after the post content.', $this->textdomain ),
			'type'    => 'checkbox',
			'std'     => false
		);
		$this->options['post_tag_style'] = array(
			'section'	=> 'general',
			'title'		=> __( 'Post Tag Style', $this->textdomain ),
			'desc'		=> __( 'Select the provided tag below for your widget tag style', $this->textdomain ),
			'type'    	=> 'select',
			'opts'		=> array( 
				'' 								=> esc_attr__( 'No Style', $this->textdomain ), 
				'bluerr' 						=> esc_attr__( 'Bluerr', $this->textdomain ), 
				'green' 						=> esc_attr__( 'Green', $this->textdomain ),
				'orange' 						=> esc_attr__( 'Orange', $this->textdomain ),
				'orange2' 						=> esc_attr__( 'Orange 2', $this->textdomain ),	
				'red' 							=> esc_attr__( 'Red', $this->textdomain ),
				'yellow' 						=> esc_attr__( 'Yellow', $this->textdomain ),
				'r-orange' 						=> esc_attr__( 'Orange Rounded', $this->textdomain ),
				'r-green' 						=> esc_attr__( 'Green Rounded', $this->textdomain ),
				'r-blue' 						=> esc_attr__( 'Blue Rounded', $this->textdomain ),
				'r-red' 						=> esc_attr__( 'Red Rounded', $this->textdomain ),
				'r-grey' 						=> esc_attr__( 'Grey Rounded', $this->textdomain ),
				'r-black' 						=> esc_attr__( 'Black Rounded', $this->textdomain ),
				'r-cyan' 						=> esc_attr__( 'Cyan Rounded', $this->textdomain ),
				't-black' 						=> esc_attr__( 'Trimmed Black', $this->textdomain ),
				't-blue' 						=> esc_attr__( 'Trimmed Blue', $this->textdomain ),
				't-cyan' 						=> esc_attr__( 'Trimmed Cyan', $this->textdomain ),
				't-green' 						=> esc_attr__( 'Trimmed Green', $this->textdomain ),
				't-grey' 						=> esc_attr__( 'Trimmed Grey', $this->textdomain ),
				't-orange' 						=> esc_attr__( 'Trimmed Orange', $this->textdomain ),
				't-red' 						=> esc_attr__( 'Trimmed Red', $this->textdomain ),
				'btn extended-tags-btn-silver'	=> esc_attr__( 'Button Silver', $this->textdomain ),
				'btn extended-tags-btn-blue'	=> esc_attr__( 'Button Blue', $this->textdomain ),
				'btn extended-tags-btn-sky'		=> esc_attr__( 'Button Sky Blue', $this->textdomain ),
				'btn extended-tags-btn-orange'	=> esc_attr__( 'Button Orange', $this->textdomain ),
				'btn extended-tags-btn-green'	=> esc_attr__( 'Button Green', $this->textdomain ),
				'btn extended-tags-btn-black'	=> esc_attr__( 'Button Black', $this->textdomain ),
				'btn extended-tags-btn-red'		=> esc_attr__( 'Button Red', $this->textdomain )
			),
			'std'		=> array( 'btn extended-tags-btn-orange' )
		);				
		
		
		/* Advanced Settings
		===========================================*/
		$this->options['enable_custom'] = array(
			'section' => 'advanced',
			'title'   => __( 'Enable Custom', $this->textdomain ),
			'desc'    => __( 'Check this to push the style script option below', $this->textdomain ),
			'type'    => 'checkbox',
			'std'     => false
		);
		$this->options['custom'] = array(
			'section' => 'advanced',
			'title'   => __( 'Custom Style & Script', $this->textdomain ),
			'desc'    => __( 'Use this option to add additional styles or script with the tag included.', $this->textdomain ),
			'type'    => 'textarea',
			'std'     => ''
		);
	}
	
	function print_custom() {
		$option = get_option( $this->slug );
		if( isset( $option['enable_custom'] ) )
			echo $option['custom'];
	}
} // end class.

new Extended_Tags_Settings();
?>