<?php
/**
 * The Tags widget replaces the default WordPress Tag Cloud widget. This version gives total
 * control over the output to the user by allowing the input of all the arguments typically seen
 * in the wp_tag_cloud() function.
 *
 * @package Extended Tags Widget
 * @subpackage Classes
 */

/**
 * Extended Tags Widget Widget Class
 * @link http://codex.wordpress.org/Template_Tags/wp_tag_cloud
 */
class Extended_Tags_Widget extends WP_Widget {

	// Variables for theme or plugin developper
	var $prefix;
	var $textdomain;

	/**
	 * Set up the widget's unique name, ID, class, description, and other options.
	 * @since 1.0
	 */
	function __construct() {

		// Set the widget variables
		$this->prefix = '';
		$this->textdomain = 'extended-tags-widget';
		
		// Set up the widget options
		$widget_options = array(
			'classname' => 'tags',
			'description' => esc_html__( '[+] An advanced widget that gives you total control over the output of your tags.', $this->textdomain )
		);

		// Set up the widget control options
		$control_options = array(
			'width' => 420,
			'height' => 350,
			'id_base' => "{$this->prefix}extended-tags"
		);

		// Create the widget
		$this->WP_Widget( "{$this->prefix}extended-tags", esc_attr__( 'Extended Tags', $this->textdomain ), $widget_options, $control_options );
		
		// Print the user costum style sheet
		add_action( 'load-widgets.php', array(&$this, 'load_widgets') );
		
		// Print the user costum style sheet
		if ( is_active_widget( false, false, $this->id_base, false ) &&  ! is_admin() ) {
			wp_enqueue_script( 'jquery' );
			wp_enqueue_style( 'extended-tags-widget', EXTENDED_TAGS_WIDGET_URL . 'css/widget.css', EXTENDED_TAGS_WIDGET_VERSION );
			add_action( 'wp_head', array( &$this, 'custom_head') );
		}		
	}

	
	/**
	 * Push the widget stylesheet widget.css into widget admin page
	 * @since 1.0
	 */		
	function load_widgets() {	
		wp_enqueue_media();
		wp_enqueue_style('total-dialog');
		wp_enqueue_script('total-dialog');
		wp_enqueue_style( 'extended-tags-widget', EXTENDED_TAGS_WIDGET_URL . 'css/widget.css', EXTENDED_TAGS_WIDGET_VERSION );
	}
	
	
	/**
	 * Print the custom script-style to the header wp_head
	 * @since 1.0
	 */	
	function custom_head() {
		$all_widgets = $this->get_settings();
		foreach ($all_widgets as $key => $setting){
			$widget_id = $this->id_base . '-' . $key;
			if( is_active_widget( false, $widget_id, $this->id_base ) ){
				
				// Print the widget background image
				echo '<style type="text/css">';
					if ( $setting['bgImage'] )		echo '#' . $this->id . ' {background: url(' . $setting['bgImage'] . ') no-repeat scroll 0 0 transparent}';
				echo '</style>';			
			
				if ( !empty( $setting['customstylescript'] ) )
					echo $setting['customstylescript'];
			}
		}		
	}
	

	/**
	 * Outputs the widget based on the arguments input through the widget controls.
	 * @since 1.0
	 */
	function widget( $args, $instance ) {
		extract( $args );

		// Set up the arguments
		$args = array(
			'id'				=>	$this->id,
			'title_icon'		=>	$instance['title_icon'],
			'taxonomy'			=>	$instance['taxonomy'],
			'largest'			=> 	! empty( $instance['largest'] ) ? absint( $instance['largest'] ) : 22,
			'smallest'			=>	! empty( $instance['smallest'] ) ? absint( $instance['smallest'] ) : 8,
			'number'			=>	intval( $instance['number'] ),
			'child_of'			=>	intval( $instance['child_of'] ),
			'parent'			=>	! empty( $instance['parent'] ) ? intval( $instance['parent'] ) : '',
			'separator'			=>	! empty( $instance['separator'] ) ? $instance['separator'] : "\n",
			'pad_counts'		=>	! empty( $instance['pad_counts'] ) ? true : false,
			'hide_empty'		=>	! empty( $instance['hide_empty'] ) ? true : false,
			'current_tags'		=>	! empty( $instance['current_tags'] ) ? true : false,
			'unit'				=>	$instance['unit'],
			'display'			=>	isset( $instance['display'] ) ? $instance['display'] : 'flat',
			'style'				=>	$instance['style'],
			'include'			=>	! empty( $instance['include'] ) ? join( ', ', $instance['include'] ) : '',
			'exclude'			=>	! empty( $instance['exclude'] ) ? join( ', ', $instance['exclude'] ) : '',
			'order'				=>	$instance['order'],
			'orderby'			=>	$instance['orderby'],
			'link'				=>	$instance['link'],
			'search'			=>	$instance['search'],
			'name__like'		=>	$instance['name__like'],
			'bgImage'			=>	$instance['bgImage'],
			'toggle_active'		=>	$instance['toggle_active'],
			'intro_text' 		=>	$instance['intro_text'],
			'outro_text' 		=>	$instance['outro_text'],
			'customstylescript'	=>	$instance['customstylescript'],			
			'echo'				=>	false,
			'topic_count_text_callback'	=> array(&$this, 'topic_count_text')
		);

		// Output the theme's $before_widget wrapper
		echo $before_widget;

		// If a title was input by the user, display it.
		if ( !empty( $instance['title_icon'] ) )
			$titleIcon = '<img class="titleIcon" alt="" src="' . $instance['title_icon'] . '" />';
		else
			$titleIcon = '';	
		
		// If a title was input by the user, display it
		if ( !empty( $instance['title'] ) )
			echo $before_title . $titleIcon . apply_filters( 'widget_title',  $instance['title'], $instance, $this->id_base ) . $after_title;

		// Output the extended tags
		echo extended_tags( $args );

		// Close the theme's widget wrapper
		echo $after_widget;
	}
	
	
	/**
	 * Create a callback function for tag count text
	 * Default 'topic' for singular and 'topics' for plural
	 * @since 1.1.1
	 */
	function topic_count_text( $count ) {
		return sprintf( _n("%s topic", "%s topics", $count), number_format_i18n( $count ) );
	}

	
	/**
	 * Updates the widget control options for the particular instance of the widget.
	 * @since 1.0
	 */
	function update( $new_instance, $old_instance ) {
		$instance = $old_instance;

		// Set the instance to the new instance.
		$instance = $new_instance;

		// If new taxonomy is chosen, reset includes and excludes.
		if ( $instance['taxonomy'] !== $old_instance['taxonomy'] ) {
			$instance['include'] = array();
			$instance['exclude'] = array();
		}

		$instance['title'] 				= strip_tags( $new_instance['title'] );
		$instance['title_icon']			= strip_tags( $new_instance['title_icon'] );
		$instance['smallest'] 			= strip_tags( $new_instance['smallest'] );
		$instance['largest'] 			= strip_tags( $new_instance['largest'] );
		$instance['number'] 			= (int) $new_instance['number'];
		$instance['separator'] 			= strip_tags( $new_instance['separator'] );
		$instance['name__like'] 		= strip_tags( $new_instance['name__like'] );
		$instance['search'] 			= strip_tags( $new_instance['search'] );
		$instance['child_of'] 			= strip_tags( $new_instance['child_of'] );
		$instance['parent'] 			= strip_tags( $new_instance['parent'] );
		$instance['unit'] 				= $new_instance['unit'];
		$instance['display'] 			= $new_instance['display'];
		$instance['style'] 				= $new_instance['style'];
		$instance['orderby'] 			= $new_instance['orderby'];		
		$instance['order'] 				= $new_instance['order'];
		$instance['taxonomy'] 			= $new_instance['taxonomy'];
		$instance['link'] 				= $new_instance['link'];
		$instance['pad_counts'] 		= isset( $new_instance['pad_counts'] ) ? 1 : 0;
		$instance['hide_empty'] 		= isset( $new_instance['hide_empty'] ) ? 1 : 0;
		$instance['current_tags'] 		= isset( $new_instance['current_tags'] ) ? 1 : 0;
		$instance['bgImage'] 			= $new_instance['bgImage'];
		$instance['toggle_active'] 		= $new_instance['toggle_active'];		
		$instance['intro_text'] 		= $new_instance['intro_text'];
		$instance['outro_text'] 		= $new_instance['outro_text'];
		$instance['customstylescript']	= $new_instance['customstylescript'];
		
		return $instance;
	}

	/**
	 * Displays the widget control options in the Widgets admin screen.
	 * @since 1.0
	 */
	function form( $instance ) {

		// Merge the user-selected arguments with the defaults.
		$instance = wp_parse_args( (array) $instance, extended_tags_defaults_args() );

		$taxonomies = get_taxonomies( array( 'show_tagcloud' => true ), 'objects' );
		$terms = get_terms( $instance['taxonomy'], 'hide_empty=0' ); // update 1.2.1 to show the empty taxonomy.		
		$link = array( 'view' => esc_attr__( 'View', $this->textdomain ), 'edit' => esc_attr__( 'Edit', $this->textdomain ) );
		$displays = array( 'flat' => esc_attr__( 'Flat', $this->textdomain ), 'list' => esc_attr__( 'List', $this->textdomain ) );
		$style = array( 
			'' 								=> esc_attr__( 'No Style', $this->textdomain ), 
			'bluerr' 						=> esc_attr__( 'Bluerr', $this->textdomain ), 
			'green' 						=> esc_attr__( 'Green', $this->textdomain ),
			'orange' 						=> esc_attr__( 'Orange', $this->textdomain ),
			'orange2' 						=> esc_attr__( 'Orange 2', $this->textdomain ),	
			'red' 							=> esc_attr__( 'Red', $this->textdomain ),
			'yellow' 						=> esc_attr__( 'Yellow', $this->textdomain ),
			'r-orange' 						=> esc_attr__( 'Orange Rounded', $this->textdomain ),
			'r-green' 						=> esc_attr__( 'Green Rounded', $this->textdomain ),
			'r-blue' 						=> esc_attr__( 'Blue Rounded', $this->textdomain ),
			'r-red' 						=> esc_attr__( 'Red Rounded', $this->textdomain ),
			'r-grey' 						=> esc_attr__( 'Grey Rounded', $this->textdomain ),
			'r-black' 						=> esc_attr__( 'Black Rounded', $this->textdomain ),
			'r-cyan' 						=> esc_attr__( 'Cyan Rounded', $this->textdomain ),
			't-black' 						=> esc_attr__( 'Trimmed Black', $this->textdomain ),
			't-blue' 						=> esc_attr__( 'Trimmed Blue', $this->textdomain ),
			't-cyan' 						=> esc_attr__( 'Trimmed Cyan', $this->textdomain ),
			't-green' 						=> esc_attr__( 'Trimmed Green', $this->textdomain ),
			't-grey' 						=> esc_attr__( 'Trimmed Grey', $this->textdomain ),
			't-orange' 						=> esc_attr__( 'Trimmed Orange', $this->textdomain ),
			't-red' 						=> esc_attr__( 'Trimmed Red', $this->textdomain ),
			'btn extended-tags-btn-silver'	=> esc_attr__( 'Button Silver', $this->textdomain ),
			'btn extended-tags-btn-blue'	=> esc_attr__( 'Button Blue', $this->textdomain ),
			'btn extended-tags-btn-sky'		=> esc_attr__( 'Button Sky Blue', $this->textdomain ),
			'btn extended-tags-btn-orange'	=> esc_attr__( 'Button Orange', $this->textdomain ),
			'btn extended-tags-btn-green'	=> esc_attr__( 'Button Green', $this->textdomain ),
			'btn extended-tags-btn-black'	=> esc_attr__( 'Button Black', $this->textdomain ),
			'btn extended-tags-btn-red'		=> esc_attr__( 'Button Red', $this->textdomain )
			
		);
		$order = array( 'ASC' => esc_attr__( 'Ascending', $this->textdomain ), 'DESC' => esc_attr__( 'Descending', $this->textdomain ), 'RAND' => esc_attr__( 'Random', $this->textdomain ) );
		$orderby = array( 
			'count' => esc_attr__( 'Count', $this->textdomain ), 
			'name' => esc_attr__( 'Name', $this->textdomain ),
			'slug' => esc_attr__( 'Slug', $this->textdomain ),
			'term_group' => esc_attr__( 'Term Group', $this->textdomain ) ,
			'id' => esc_attr__( 'Id', $this->textdomain ) 
		);
		$unit = array( 'pt' => 'pt', 'px' => 'px', 'em' => 'em', '%' => '%' );
		$intro_text	= esc_textarea($instance['intro_text']);
		$outro_text	= esc_textarea($instance['outro_text']);
		
		$tabs = array( 
			__( 'General', $this->textdomain ),  
			__( 'Style', $this->textdomain ),
			__( 'Advanced', $this->textdomain ),
			__( 'Template', $this->textdomain ),
			__( 'Customs', $this->textdomain ),
			__( 'Supports', $this->textdomain )
		);		
		?>
		<div class="pluginName">Extended Tags Widget<span class="pluginVersion"><?php echo EXTENDED_TAGS_WIDGET_VERSION; ?></span></div>
		<div id="extw-<?php echo $this->id ; ?>" class="total-options tabbable tabs-left">
			
			<ul class="nav nav-tabs">
				<?php foreach ($tabs as $key => $tab ) : ?>
					<li class="<?php echo $instance['toggle_active'][$key] ? 'active' : '' ; ?>"><?php echo $tab; ?><input type="hidden" name="<?php echo $this->get_field_name( 'toggle_active' ); ?>[]" value="<?php echo $instance['toggle_active'][$key]; ?>" /></li>
				<?php endforeach; ?>							
			</ul>	
			
			<ul class="tab-content">
				<li class="tab-pane <?php if ( $instance['toggle_active'][0] ) : ?>active<?php endif; ?>">
					<ul>
						<li>
							<label for="<?php echo $this->get_field_id( 'title' ); ?>"><?php _e( 'Title', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Give this widget title, let it empty to hide the title', $this->textdomain ); ?></span>
							<input type="text" class="widefat" id="<?php echo $this->get_field_id( 'title' ); ?>" name="<?php echo $this->get_field_name( 'title' ); ?>" value="<?php echo esc_attr( $instance['title'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'taxonomy' ); ?>"><?php _e( 'Taxonomy', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Select the given taxonomy below. Another registered custom taxonomy also listed below if available.', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'taxonomy' ); ?>" name="<?php echo $this->get_field_name( 'taxonomy' ); ?>">
								<?php foreach ( $taxonomies as $taxonomy ) { ?>
									<option value="<?php echo $taxonomy->name; ?>" <?php selected( $instance['taxonomy'], $taxonomy->name ); ?>><?php echo $taxonomy->name; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'link' ); ?>"><?php _e( 'Link', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Set link to allow edit of a particular tag.', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'link' ); ?>" name="<?php echo $this->get_field_name( 'link' ); ?>">
								<?php foreach ( $link as $option_value => $option_label ) { ?>
									<option value="<?php echo $option_value; ?>" <?php selected( $instance['link'], $option_value ); ?>><?php echo $option_label; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'order' ); ?>"><?php _e( 'Order', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Order the tags by ascending, descending, or random', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'order' ); ?>" name="<?php echo $this->get_field_name( 'order' ); ?>">
								<?php foreach ( $order as $option_value => $option_label ) { ?>
									<option value="<?php echo $option_value; ?>" <?php selected( $instance['order'], $option_value ); ?>><?php echo $option_label; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'orderby' ); ?>"><?php _e( 'Order By', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Order the tags by custom type', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'orderby' ); ?>" name="<?php echo $this->get_field_name( 'orderby' ); ?>">
								<?php foreach ( $orderby as $option_value => $option_label ) { ?>
									<option value="<?php echo $option_value; ?>" <?php selected( $instance['orderby'], $option_value ); ?>><?php echo $option_label; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'number' ); ?>"><?php _e( 'Number', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'The number of actual tags to display in the widget. Use 0 to display all tags.', $this->textdomain ); ?></span> 
							<input type="text" id="<?php echo $this->get_field_id( 'number' ); ?>" name="<?php echo $this->get_field_name( 'number' ); ?>" value="<?php echo esc_attr( $instance['number'] ); ?>" />
						</li>
					</ul>
				</li>
				
				<li class="tab-pane <?php if ( $instance['toggle_active'][1] ) : ?>active<?php endif; ?>">
					<ul>
						<li>
							<label for="<?php echo $this->get_field_id( 'display' ); ?>"><?php _e( 'Display', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Displays the tags in flat (separated by whitespace) style.', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'display' ); ?>" name="<?php echo $this->get_field_name( 'display' ); ?>">
								<?php foreach ( $displays as $option_value => $option_label ) { ?>
									<option value="<?php echo $option_value; ?>" <?php selected( $instance['display'], $option_value ); ?>><?php echo $option_label; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'separator' ); ?>"><?php _e( 'Separator', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'The text/space between tags.', $this->textdomain ); ?></span> 
							<input type="text" id="<?php echo $this->get_field_id( 'separator' ); ?>" name="<?php echo $this->get_field_name( 'separator' ); ?>" value="<?php echo esc_attr( $instance['separator'] ); ?>" />
						</li>						
						<li>
							<label for="<?php echo $this->get_field_id( 'largest' ); ?>"><?php _e( 'Largest & Smallest', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'The text size of the tag with the highest and smallest count value (units given by unit parameter).', $this->textdomain ); ?></span> 
							<input class="smallfat" type="text" id="<?php echo $this->get_field_id( 'largest' ); ?>" name="<?php echo $this->get_field_name( 'largest' ); ?>" value="<?php echo esc_attr( $instance['largest'] ); ?>" />					
							<input class="smallfat" type="text" id="<?php echo $this->get_field_id( 'smallest' ); ?>" name="<?php echo $this->get_field_name( 'smallest' ); ?>" value="<?php echo esc_attr( $instance['smallest'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'unit' ); ?>"><?php _e( 'Unit', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Unit of measure as pertains to the smallest and largest values. This can be any CSS length value, e.g. pt, px, em, %.', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'unit' ); ?>" name="<?php echo $this->get_field_name( 'unit' ); ?>">
								<?php foreach ( $unit as $option_value => $option_label ) { ?>
									<option value="<?php echo $option_value; ?>" <?php selected( $instance['unit'], $option_value ); ?>><?php echo $option_label; ?></option>
								<?php } ?>
							</select>
						</li>
					</ul>
				</li>
				
				<li class="tab-pane <?php if ( $instance['toggle_active'][2] ) : ?>active<?php endif; ?>">
					<ul>
						<li>
							<label for="<?php echo $this->get_field_id( 'include' ); ?>"><?php _e( 'Include', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Select the terms below to include in the widget', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'include' ); ?>" name="<?php echo $this->get_field_name( 'include' ); ?>[]" size="4" multiple="multiple">
								<?php foreach ( $terms as $term ) { ?>
									<option value="<?php echo $term->term_id; ?>" <?php echo ( in_array( $term->term_id, (array) $instance['include'] ) ? 'selected="selected"' : '' ); ?>><?php echo $term->name; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'exclude' ); ?>"><?php _e( 'Exclude', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Select the terms below to exclude in the widget.', $this->textdomain ); ?></span> 
							<select id="<?php echo $this->get_field_id( 'exclude' ); ?>" name="<?php echo $this->get_field_name( 'exclude' ); ?>[]" size="4" multiple="multiple">
								<?php foreach ( $terms as $term ) { ?>
									<option value="<?php echo $term->term_id; ?>" <?php echo ( in_array( $term->term_id, (array) $instance['exclude'] ) ? 'selected="selected"' : '' ); ?>><?php echo $term->name; ?></option>
								<?php } ?>
							</select>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'child_of' ); ?>"><?php _e( 'Child Of', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Use this only for displaying the child categories or custom taxonomies.', $this->textdomain ); ?></span> 
							<input type="text" id="<?php echo $this->get_field_id( 'child_of' ); ?>" name="<?php echo $this->get_field_name( 'child_of' ); ?>" value="<?php echo esc_attr( $instance['child_of'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'parent' ); ?>"><?php _e( 'Parent', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Use this only for displaying the the parent categories or custom taxonomies.', $this->textdomain ); ?></span> 
							<input type="text" id="<?php echo $this->get_field_id( 'parent' ); ?>" name="<?php echo $this->get_field_name( 'parent' ); ?>" value="<?php echo esc_attr( $instance['parent'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'search' ); ?>"><?php _e( 'Search', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Use this only for displaying spesific taxonomies', $this->textdomain ); ?></span> 
							<input type="text" id="<?php echo $this->get_field_id( 'search' ); ?>" name="<?php echo $this->get_field_name( 'search' ); ?>" value="<?php echo esc_attr( $instance['search'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'name__like' ); ?>"><?php _e( 'Name Like', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Use this only for displaying spesific taxonomies that have name like ...', $this->textdomain ); ?></span> 
							<input type="text" id="<?php echo $this->get_field_id( 'name__like' ); ?>" name="<?php echo $this->get_field_name( 'name__like' ); ?>" value="<?php echo esc_attr( $instance['name__like'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'pad_counts' ); ?>">
							<input class="checkbox" type="checkbox" <?php checked( $instance['pad_counts'], true ); ?> id="<?php echo $this->get_field_id( 'pad_counts' ); ?>" name="<?php echo $this->get_field_name( 'pad_counts' ); ?>" /> <?php _e( 'Show pad counts?', $this->textdomain ); ?></label>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'hide_empty' ); ?>">
							<input class="checkbox" type="checkbox" <?php checked( $instance['hide_empty'], true ); ?> id="<?php echo $this->get_field_id( 'hide_empty' ); ?>" name="<?php echo $this->get_field_name( 'hide_empty' ); ?>" /> <?php _e( 'Hide tags with empty post?', $this->textdomain ); ?></label>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'current_tags' ); ?>">
							<input class="checkbox" type="checkbox" <?php checked( $instance['current_tags'], true ); ?> id="<?php echo $this->get_field_id( 'current_tags' ); ?>" name="<?php echo $this->get_field_name( 'current_tags' ); ?>" /> <?php _e( 'Only display current post terms?', $this->textdomain ); ?></label>
						</li>
					</ul>
				</li>
				
				<li class="tab-pane <?php if ( $instance['toggle_active'][3] ) : ?>active<?php endif; ?>">
					<ul>
						<li>
							<label for="<?php echo $this->get_field_id( 'style' ); ?>"><?php _e( 'Style', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Select the provided tag below for your widget tag style', $this->textdomain ); ?></span> 
							<select onchange="wpWidgets.save(jQuery(this).closest('div.widget'),0,1,0);" id="<?php echo $this->get_field_id( 'style' ); ?>" name="<?php echo $this->get_field_name( 'style' ); ?>">
								<?php foreach ( $style as $option_value => $option_label ) { ?>
									<option value="<?php echo $option_value; ?>" <?php selected( $instance['style'], $option_value ); ?>><?php echo $option_label; ?></option>
								<?php } ?>
							</select>
							<div class="extended-tags" style="margin-top: 10px;">
								<p class="extended-tags-<?php echo $instance['style']; ?>">
									<a style="font-size: 8pt;" title="1 topic" class="tag-link-36" href="#"><span>adipiscing</span></a> 
									<a style="font-size: 22pt;" title="4 topics" class="tag-link-33" href="#"><span>ante</span></a> 
									<a style="font-size: 8pt;" title="1 topic" class="tag-link-16" href="#"><span>back</span></a> 
									<a style="font-size: 14.3pt;" title="2 topics" class="tag-link-54" href="#"><span>code</span></a> 
									<a style="font-size: 14.3pt;" title="2 topics" class="tag-link-26" href="#"><span>columns</span></a> 
									<a style="font-size: 14.3pt;" title="2 topics" class="tag-link-56" href="#"><span>credits</span></a> 
									<a style="font-size: 18.5pt;" title="3 topics" class="tag-link-29" href="#"><span>csras</span></a> 
									<a style="font-size: 8pt;" title="1 topic" class="tag-link-18" href="#"><span>deactivate</span></a>
									<br class="clear">
								</p>
							</div>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'title_icon' ); ?>"><?php _e( 'Widget Title Icon', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'Attach an image or icon for the widget title', $this->textdomain ); ?></span>
							<img alt="" class="optionImage" src="<?php echo esc_attr( $instance['title_icon'] ); ?>">
							<a href="#" class="add-image button"><?php _e( 'Add Image', $this->textdomain ); ?></a>
							<a class="<?php if ( empty($instance['title_icon'] ) ) : ?>hidden <?php endif; ?>remove-image button" href="#"><?php _e('Remove', $this->textdomain); ?></a>
							<input type="hidden" id="<?php echo $this->get_field_id( 'title_icon' ); ?>" name="<?php echo $this->get_field_name( 'title_icon' ); ?>" value="<?php echo esc_attr( $instance['title_icon'] ); ?>" />
						</li>
						<li>
							<label for="<?php echo $this->get_field_id( 'bgImage' ); ?>"><?php _e( 'Background Image', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'The counter background image.', $this->textdomain ); ?></span>									
							<img alt="" class="optionImage" src="<?php echo esc_attr( $instance['bgImage'] ); ?>">
							<a href="#" class="add-image button"><?php _e( 'Add Image', $this->textdomain ); ?></a>
							<a class="<?php if ( empty($instance['bgImage'] ) ) : ?>hidden <?php endif; ?>remove-image button" href="#"><?php _e('Remove', $this->textdomain); ?></a>
							<input type="hidden" id="<?php echo $this->get_field_id( 'bgImage' ); ?>" name="<?php echo $this->get_field_name( 'bgImage' ); ?>" value="<?php echo esc_attr( $instance['bgImage'] ); ?>" />
						</li>							
					</ul>
				</li>				
				
				<li class="tab-pane <?php if ( $instance['toggle_active'][4] ) : ?>active<?php endif; ?>">
					<ul>										
						<li>
							<label><?php _e( 'Shortcode & Function', $this->textdomain ) ; ?></label>
							<span class="description">								
								<?php _e( '<strong>Note</strong>: Drag this widget to the "Inactive Widgets" at the bottom of this page if you want to use this as a shortcode to your content or PHP function in your template with the codes above.', $this->textdomain ); ?><br />
								<span class="shortcode">
									<?php _e( 'Shortcode: ', $this->textdomain ); ?><?php echo '[extended-tags id="' . $this->number . '"]'; ?><br />
									<?php _e( 'Function: ', $this->textdomain ); ?><?php echo '&lt;?php extended_tags(' . $this->number . '); ?&gt;'; ?>						
								</span>
							</span>
						</li>										
						<li>
							<label for="<?php echo $this->get_field_id('intro_text'); ?>"><?php _e( 'Intro Text', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'This option will display addtional text before the widget content and supports HTML.', $this->textdomain ); ?></span>
							<textarea name="<?php echo $this->get_field_name( 'intro_text' ); ?>" id="<?php echo $this->get_field_id( 'intro_text' ); ?>" rows="2" class="widefat"><?php echo $intro_text; ?></textarea>
						</li>
						<li>
							<label for="<?php echo $this->get_field_id('outro_text'); ?>"><?php _e( 'Outro Text', $this->textdomain ); ?></label>
							<span class="description"><?php _e( 'This option will display addtional text after widget and supports HTML.', $this->textdomain ); ?></span>
							<textarea name="<?php echo $this->get_field_name( 'outro_text' ); ?>" id="<?php echo $this->get_field_id( 'outro_text' ); ?>" rows="2" class="widefat"><?php echo $outro_text; ?></textarea>
						</li>	
						<li>
							<label for="<?php echo $this->get_field_id('customstylescript'); ?>"><?php _e( 'Custom Script & Stylesheet', $this->textdomain );?></label>
							<span class="description"><?php _e( 'Use this box for additional widget CSS style of custom javascript. Current widget selector: ', $this->textdomain ); ?><?php echo '<br /><tt>#' . $this->id . '</tt>'; ?></span>
							<textarea name="<?php echo $this->get_field_name( 'customstylescript' ); ?>" id="<?php echo $this->get_field_id( 'customstylescript' ); ?>" rows="3" class="widefat code"><?php echo htmlentities($instance['customstylescript']); ?></textarea>
						</li>
					</ul>
				</li>
				
				<li class="tab-pane <?php if ( $instance['toggle_active'][5] ) : ?>active<?php endif; ?>">
					<ul>
						<li>
							<h3>Support and Contribute</h3>
							<p>Please ask us for supports or new features here:<p>
							<a href="http://codecanyon.net/user/zourbuth#message?ref=zourbuth">CodeCanyon Author Profile Page</a><br />
							<a href="http://codecanyon.net/item/extended-tags-widget-wordpress-premium-plugin/discussion/464929?ref=zourbuth">Plugin Discussion</a>
						</li>
					</ul>
				</li>			
			</ul>
		</div>
	<?php
	}
}

?>